Crate win_task_dialog[−][src]
Structs
| TaskDialogButton | |
| TaskDialogConfig | |
| TaskDialogResult |
Constants
Functions
| show_msg_dialog | Show message dialog, the dialog have only the OK button |
| show_task_dialog | Show task dialog |
| TaskDialogButton | |
| TaskDialogConfig | |
| TaskDialogResult |
| show_msg_dialog | Show message dialog, the dialog have only the OK button |
| show_task_dialog | Show task dialog |